(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    337945,       5837]
NotebookOptionsPosition[    335002,       5742]
NotebookOutlinePosition[    335468,       5760]
CellTagsIndexPosition[    335425,       5757]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "\n",
 StyleBox["K-Means Clustering ", "Title"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.591246793279451*^9, 3.591246797992347*^9}}],

Cell[TextData[{
 StyleBox["An algorithm for partitioning or (clusetring) N data points into ",
  FontSize->14],
 Cell[BoxData[
  FormBox["K", TraditionalForm]],
  FontSize->14],
 StyleBox[" disjoint subsets ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "j"], TraditionalForm]],
  FontSize->14],
 StyleBox["containing ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["N", "j"], TraditionalForm]],
  FontSize->14],
 StyleBox[" data points so as minimize the sum-of-squares criterion\n\n",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"J", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "K"], 
      RowBox[{
       UnderscriptBox["\[Sum]", 
        RowBox[{"n", "=", 
         SubscriptBox["S", "j"]}]], 
       SuperscriptBox[
        RowBox[{"\[LeftBracketingBar]", 
         RowBox[{
          SubscriptBox["x", "n"], "-", 
          SubscriptBox["\[Mu]", "j"]}], "\[RightBracketingBar]"}], "2"]}]}]}],
     ","}], TraditionalForm]],
  FontSize->18],
 StyleBox["\n\nWhere ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "n"], TraditionalForm]],
  FontSize->14],
 StyleBox["is a vector representing the ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptN]th", " "}], TraditionalForm]],
  FontSize->14],
 StyleBox["data point and",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Mu]", "j"], TraditionalForm]],
  FontSize->14],
 StyleBox["is the geometric centroid of the data points in ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["S", "j"], "."}], TraditionalForm]],
  FontSize->14],
 StyleBox[" In general, the algorithm does not achieve a global minimum of ",
  FontSize->14],
 Cell[BoxData[
  FormBox["J", TraditionalForm]],
  FontSize->14],
 StyleBox[" over the assignments. In fact, sine the algorithm uses discrete \
assignment rather than a set of continuous parameters, the \
\[OpenCurlyDoubleQuote]minimum\[CloseCurlyDoubleQuote] it reaches cannot even \
be properly called a local minimum. Despite these limitations, the algorithm \
is used fairly frequently as a result of its ease of implementation. \n\nThe \
algorithm consists of a simple re-estimation procedure as follows. Initially, \
the data points are assigned at random to the K sets. For step 1, the \
centroid is computed for each set. In step 2, every point is assigned to the \
cluster whose centroid is closest to that point. These two steps are \
alternated until a stopping criterion is met, i.e., when there is no further \
change in the assignment of the data points.\n\n",
  FontSize->14],
 "Source: http://mathworld.wolfram.com/K-MeansClusteringAlgorithm.html "
}], "Text",
 CellChangeTimes->{{3.591245871729959*^9, 3.591245886131031*^9}, {
  3.591562917532033*^9, 3.59156294805345*^9}, {3.591570818604151*^9, 
  3.591570832199778*^9}, {3.591571318284692*^9, 3.591571318715342*^9}, {
  3.591571369909189*^9, 3.591571587053854*^9}, {3.591571623911644*^9, 
  3.5915716245620213`*^9}, {3.5915716603178177`*^9, 3.591571758998685*^9}, {
  3.5915717955995293`*^9, 3.591571900520789*^9}}],

Cell[TextData[{
 "\n\n",
 StyleBox["Numerical or textual data could be clusterized in no matter what \
format for input and output:",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.59124638868224*^9, 3.591246419664015*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["2 clusters",
  FontSize->14]
}], "Text",
 CellChangeTimes->{{3.591246438598722*^9, 3.591246446292964*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ClusteringComponents", "[", 
    RowBox[{
     TagBox[
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "2", "2", "2", "1"},
          {"1", "1", "1", "5", "5"},
          {"1", "1", "5", "5", "5"},
          {"1", "1", "5", "5", "6"},
          {"1", "1", "4", "5", "6"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]], ",", "2", ",", 
     RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ",
    "Colorize"}]}]], "Input",
 CellChangeTimes->{{3.5912461133735123`*^9, 3.5912461228212633`*^9}, {
  3.591246278905593*^9, 3.59124628823104*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[{{{197, 217, 187}, {197, 217, 187}, {197, 217, 187}, {197, 
    217, 187}, {197, 217, 187}}, {{197, 217, 187}, {197, 217, 187}, {197, 217,
     187}, {207, 58, 218}, {207, 58, 218}}, {{197, 217, 187}, {197, 217, 
    187}, {207, 58, 218}, {207, 58, 218}, {207, 58, 218}}, {{197, 217, 187}, {
    197, 217, 187}, {207, 58, 218}, {207, 58, 218}, {207, 58, 218}}, {{197, 
    217, 187}, {197, 217, 187}, {207, 58, 218}, {207, 58, 218}, {207, 58, 
    218}}}, {{0, 5}, {5, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{5, 5},
  PlotRange->{{0, 5}, {0, 5}}]], "Output",
 CellChangeTimes->{{3.591246116743012*^9, 3.591246123098961*^9}, {
   3.5912462824576473`*^9, 3.591246288649248*^9}, 3.5912473038579903`*^9}]
}, Open  ]],

Cell["\<\

3 clusters\
\>", "Text",
 CellChangeTimes->{{3.591246452121517*^9, 3.591246453965829*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ClusteringComponents", "[", 
    RowBox[{
     TagBox[
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "2", "2", "2", "1"},
          {"1", "1", "1", "5", "5"},
          {"1", "1", "5", "5", "5"},
          {"1", "1", "5", "5", "6"},
          {"1", "1", "4", "5", "6"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]], ",", "3", ",", 
     RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ",
    "Colorize"}]}]], "Input",
 CellChangeTimes->{{3.591246128068933*^9, 3.591246133823862*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[{{{197, 217, 187}, {207, 58, 218}, {207, 58, 218}, {207, 
    58, 218}, {197, 217, 187}}, {{197, 217, 187}, {197, 217, 187}, {197, 217, 
    187}, {96, 161, 149}, {96, 161, 149}}, {{197, 217, 187}, {197, 217, 
    187}, {96, 161, 149}, {96, 161, 149}, {96, 161, 149}}, {{197, 217, 187}, {
    197, 217, 187}, {96, 161, 149}, {96, 161, 149}, {96, 161, 149}}, {{197, 
    217, 187}, {197, 217, 187}, {96, 161, 149}, {96, 161, 149}, {96, 161, 
    149}}}, {{0, 5}, {5, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{5, 5},
  PlotRange->{{0, 5}, {0, 5}}]], "Output",
 CellChangeTimes->{3.591246134357751*^9, 3.591247305506592*^9}]
}, Open  ]],

Cell["\<\

4 clusters\
\>", "Text",
 CellChangeTimes->{{3.59124645868021*^9, 3.591246461345607*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ClusteringComponents", "[", 
    RowBox[{
     TagBox[
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"1", "2", "2", "2", "1"},
          {"1", "1", "1", "5", "5"},
          {"1", "1", "5", "5", "5"},
          {"1", "1", "5", "5", "6"},
          {"1", "1", "4", "5", "6"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]], ",", "4", ",", 
     RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ",
    "Colorize"}]}]], "Input",
 CellChangeTimes->{{3.591246077878263*^9, 3.591246096903075*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[{{{197, 217, 187}, {207, 58, 218}, {207, 58, 218}, {207, 
    58, 218}, {197, 217, 187}}, {{197, 217, 187}, {197, 217, 187}, {197, 217, 
    187}, {96, 161, 149}, {96, 161, 149}}, {{197, 217, 187}, {197, 217, 
    187}, {96, 161, 149}, {96, 161, 149}, {96, 161, 149}}, {{197, 217, 187}, {
    197, 217, 187}, {96, 161, 149}, {96, 161, 149}, {96, 161, 149}}, {{197, 
    217, 187}, {197, 217, 187}, {186, 182, 180}, {96, 161, 149}, {96, 161, 
    149}}}, {{0, 5}, {5, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{5, 5},
  PlotRange->{{0, 5}, {0, 5}}]], "Output",
 CellChangeTimes->{{3.591246078712865*^9, 3.591246098346027*^9}, 
   3.5912473081746683`*^9}]
}, Open  ]],

Cell["\<\

Image, just like an array of number could be clusterized.

5 clusters\
\>", "Text",
 CellChangeTimes->{{3.591246467410137*^9, 3.591246488087102*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ClusteringComponents", "[", 
   RowBox[{
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxUvGd3FFfXtfuOcT6f97ltQEJS58qpc1IOSGQQOWOTnbDB4BswwSYqIAmB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       "], {{0, 119}, {184, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
      Selectable->False],
     BaseStyle->"ImageGraphics",
     ImageSize->Magnification[1],
     ImageSizeRaw->{184, 119},
     PlotRange->{{0, 184}, {0, 119}}], ",", "5", ",", " ", 
    RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ", 
  "Colorize"}]], "Input",
 CellChangeTimes->{{3.591245631058852*^9, 3.5912456310600758`*^9}, 
   3.591245670076583*^9, {3.591245715806511*^9, 3.59124575038836*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnUGOJMcNRQe2Fr6GruGddAR5oW1JgLQ1IBsQdBBrrzsIgtFe1zqXDek0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    "], {{0, 119}, {184, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{184, 119},
  PlotRange->{{0, 184}, {0, 119}}]], "Output",
 CellChangeTimes->{
  3.591245673232603*^9, {3.5912457510309267`*^9, 3.591245764274116*^9}, 
   3.591247309820033*^9}]
}, Open  ]],

Cell["\<\

7 clusters\
\>", "Text",
 CellChangeTimes->{{3.5912464935441093`*^9, 3.59124649623218*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ClusteringComponents", "[", 
   RowBox[{
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxUvGd3FFfXtfuOcT6f97ltQEJS58qpc1IOSGQQOWOTnbDB4BswwSYqIAmB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       "], {{0, 119}, {184, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
      Selectable->False],
     BaseStyle->"ImageGraphics",
     ImageSize->Magnification[1],
     ImageSizeRaw->{184, 119},
     PlotRange->{{0, 184}, {0, 119}}], ",", "7", ",", " ", 
    RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ", 
  "Colorize"}]], "Input",
 CellChangeTimes->{{3.591245778907988*^9, 3.591245802307497*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnT2OJMcRhReiDF2DF+AB5FFue5RBt3cB0iVACSB4EMnnHQiCLNntimaD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    "], {{0, 119}, {184, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{184, 119},
  PlotRange->{{0, 184}, {0, 119}}]], "Output",
 CellChangeTimes->{{3.591245779993928*^9, 3.591245802961321*^9}, 
   3.5912473123279247`*^9}]
}, Open  ]],

Cell["\<\

7 clusters\
\>", "Text",
 CellChangeTimes->{{3.5912465086979237`*^9, 3.591246511667036*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ClusteringComponents", "[", 
   RowBox[{
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJzs3em3bVV57/tz7r2stbeKogIiREAKESPZVsQqBosYjTFKLGKMSTzRqLFI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       "], {{0, 228}, {250, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
      Selectable->False],
     BaseStyle->"ImageGraphics",
     ImageSizeRaw->{250, 228},
     PlotRange->{{0, 250}, {0, 228}}], ",", "7", ",", " ", 
    RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ", 
  "Colorize"}]], "Input",
 CellChangeTimes->{{3.591245986606286*^9, 3.5912459902626*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnbHOM01ShVdAwG1wA1wAGaR/tgSksytBirQgob0QyLkHhIQ3/lImHIFE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    "], {{0, 228}, {250, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{250, 228},
  PlotRange->{{0, 250}, {0, 228}}]], "Output",
 CellChangeTimes->{3.591245991022647*^9, 3.5912473245000753`*^9}]
}, Open  ]],

Cell["\<\

4 clusters\
\>", "Text",
 CellChangeTimes->{{3.591246515886635*^9, 3.591246519103241*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ClusteringComponents", "[", 
   RowBox[{
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJzs3em3bVV57/tz7r2stbeKogIiREAKESPZVsQqBosYjTFKLGKMSTzRqLFI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       "], {{0, 228}, {250, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
      Selectable->False],
     BaseStyle->"ImageGraphics",
     ImageSizeRaw->{250, 228},
     PlotRange->{{0, 250}, {0, 228}}], ",", "4", ",", " ", 
    RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}], " ", "//", " ", 
  "Colorize"}]], "Input",
 CellChangeTimes->{{3.591246004686*^9, 3.591246005180366*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnU2uLLtSha+ABtNgGvRgCI8J5HsSdJEeSOgNhAEwB0Rj0652taHNKGhx
OKVjxY6f5eWfTDurQlr3qnaV02k7vliOzMq9z1/94R9/9w9/9ttvv/3TX/74
3+9+/y9/88c//v5Pf/cXP3742z/989//4c9/vPifH//974///v/147/+M3W9
nn/938e//evrxQ8tH08qdZ6+/uPff9D+Qy/aX+SnUu+kF9vFzwvqae+pt1Gh
uigLmNRbqnD+o3opKswvH14qNUsv1CXhkvwEPvU2KqhLzhP41FsKoK6AXz7U
VGpEytiBw6e9p+6uqrEn8Kn3kLrf+IJZ3X60DZYPO5VqlXtxKgm3tKe9p26q
H9AC1MuPEv4EPnVHVY0dWH3en0ndS+7FaUS7svfXsWnvqVvoVcNEtKu7ke61
atYzqVvI1jAv8lWhgmlP4FP7yz4PUx4Ak7S/PpXPDLjA5z3J1LZyr0wB7dbe
o++hEvjUVopwrdJuP7L5ksCn9hF+oLdKu7yAdS9vE/jUJopQV14NaK/aewKf
2kHqZqP8dSSXdgszSXuW8amFApZuaS+/bR3RbtMhnw1OLRdfcihjf3C0k/Ze
2i9fkNT7Cd8SlzWMewX66kRdt7qlu02TZD51quTfe8GwKbAP7+Y5Sbtr7+QY
kvlUVZLqJrwxdcWfFYRRoaJot/b+/PW3ldQDw9HZly9sagdhnkG1jL/Zl3qI
J9steNXS/WGSAidjNCM1pNTnSCIRFRLMhaE9PNodvn49o24TwaaVrfBlJ1H/
dgz81pNZ8JaKIB+Uqi7KWdzXCuYO2i2ogOSOiSwPU2pcrpGOQ26hUk4rG8uN
wy3LD69uL83ADmKHMXLdkdjfVxHnrQ4PGIu4UleUqkxSb9pkUZ6vODwV+CO/
tLqhwJVghLqt3oGdVpFzjd2Ve3Y1SEXg2SafzN9IT/PgCrgOdT9yS3GGdlvP
VGn/Er/WEX36/H4Psy/7ouw+gkovgd9fPOoM500O79Yzs2jHlUw1AaPKDVtB
Ar+zpE3h2gBw7pYEfV7KoM7Q3joSO6qI59YiKrWJDnOtV0XdpchadAdUE2m3
Jt9XwwAPx8uVwO8mWcC4CLmoY2j7ivbzNLLXVE0+Hf4usqjb11WMI+cnGbuA
9iZ7f36/amYKmwT+FjrMQ7YgmpGlgwOrwF+Dequ9g/FHeY1PujzQqef3P73l
mqFMh6oNlq74quZK2vtQj5hP4G8kSXKfqwMw+MOvQX0K7YB5AHzWMzuoD3UV
8RHa3TL4VNrlMMo6dDCPm4H1XB70z9TTu7RU0amiDuBnSl9Z8xyiajqJczuM
aGWYLAapgXNteeg/UK2og0C7QXd/dF2dp707F9zBRyvD0w5MPoHfR24VocB4
/RhhrGLtcqKc3+KkUD+PdnsibOwM7dGexaztcgA+R6CGUe8Di47IcdvbMSjU
GW8Hntln79Hi8MBHtRyYSNr7xYrMR23EFvXI0yJaMFQquUqHZ1cymLcO2tU2
p5YRbDHLSXh78cYOIk6WvuQw1Bm73buKurTWubRXgbevk/YLBIxd7r/H90Ja
OfCsYSi7HqxVItTllKuk2fKbrGSidxL4VapeQAHUp2/B0eYyHXV7KUGuEiPb
GABvt5vlSLyxcMVefsRXptPtfUPam+oZu3FYo4jsJe39JHUY+/G9NLVvDg7p
Mto79qYO4NXiKBtPe79SrcZeDfQ48E/vD1BvQrsaJ4bfdYPDq9jT3q9Rk7Gr
eFlHmhIpdYOoA3V8iKK9vDMy4Eh2H8T1jFzG5Wy8mUhjVzYVpcYs4BXtfe7N
0C7B696SAOeqc7uGmPa097lqKmMi1CVC41bJXMrN9fZuurClR/nFA5+0z5VL
u+SWMfa5wFdpZ1Kg2sCWGRNpj0YIaI+mmcDPEjB2GQ5csVfTpG9UZ9CurkQK
TlJN42xC3To8nlHSPldMGeMauyoAMPCtJbGqeDtoB7BVCwxmnJLqEdpJe1/O
yXuIod1GR6GuepAlsXXRkVFhMFzaXbyrtINxKqQt8O6CKJG0t65bqoMrufIq
NFjWzN0o4/Ew9sgbe5TLwGyj+gSvQzTyaK0i4KPtYDkqd1fV2JtQV7YfHRgB
7zauwtxq7PZNlZgk6tGPaknBWvG0k8DzNVhT+7cRtlBAO4AfA1+lSBEyQnuE
ugTMMkm6enUWEepuJ2riOBaSWBvK0sBt+fx5Xfx6/epzOYT70G6j7G79lk8Q
TaYwcH2PpL1q7K+ebV7wxh61dFN+kPbyjuTZfVFiKt//+vVvhSvan79+ZWY5
hJvQ7pqzyoKoQQS8rRywr7o+D2hXGRdNSrUhUcfAu/nugl19P3IeuXSWfxlT
+f/X+8X2bcvlHG5Le1ne0oMbLBvQCIOqr86lvUDibgTdtEeTcltGKxzZuxph
aaBMWzVQtBcd4p8j/BzaedRVNJ+/akLZVTXih7dBV1GXPUeEq26rScE48ETa
S5uy5t20q5HYgD6JK1CmzftJrTxJO1jnJtpd/8eMNdGOE9mlnUG9iXZsC3ZD
IdeKN2TX2z9TPO0nGbsM4hRvtxhf4O1VV7drpZzcfTOaox1JOdCmwKvBctJ2
EKY9Mi4VQRJ1i7dCbgfaec4lZlXa5YoxtDPTVJ08v1fg5Yzp7UWYB4Z2HnXL
uUVuEPUv4itU21IOj0E9mnI1FySB7h7xUnV2T1PwlBfKhZJ2uRoYBky7XMxN
aFfNSNqrA5DcArevJj5wCbfDaIL2dCWUT6+Yd9/8NAHa3chGUSNpx4lQ5U02
I2mvNmZQjzI9+vQ82sv7USjdj1JNtFvXArRbC7LvANoxbNixASHMjsCgHpHp
em80O5d22S2eYCLdjTpeVRUI9c7D3EyLeqj2z2cEoLoM5jLa3Ynbo9RZqrRH
LqR6SLXSDqKPBWgvDRhWmXNVaa8SiIEHtEdzx4kMDrT9l8Yk7cvJuaMA7QyE
TVu5ZINp7w4G41r1W74HjHqUfe76VIHnaZcmk+pAfTrt1aOqLXHhCkB9fP83
DlySedqZiTBLxCxdlAVf3nX0cnLuKIYoEniJcRMM9kSRtfK0R4152ptgxpeZ
+EDbDM89aR+kvUpRK719tNttulrBRrTjNqArkk9Q7cgfMfDRJuJ6u1rY5eTc
TmSpcCrtAFoFfHWoh3h4u7zjensr7Tze7oHyR/Waod3Vcnhupw7alXHZcFQT
BJ8L0I5HK48qGafAPmrmL4FsohqkuXtI6Qqkjz1devsS2gcv4rppB84sD1G0
S05URrinBrOr0u6uGE872ERU58+8J3Mt7X2QN9EeRR+gLmtdVfrajGhC/eDs
vbq7WdpLUiTtZ9POlBZTaGfOpeoNHH037grvqLGd+1zaFZlV2u3yJu3TUW+l
3Qa9FXuSdiAJsA26pd327K4Ahk3RSE4z+pSBPGnfhPbW0E+kXXVl427HYzmx
dZF7UpXLYH+JZgo+VY7B0x6leepU2q1HjdNOhl7559Nc1UY2G1EEaK8OY1zk
lJP282i37uQ6Xgf2Vdolt27tAWh/fK/JI6hcfprkZhPJdtK+CvhWP4/YHqe9
9KxotxmqeO6gXc29g/Y+4OWB1R0En2U5P/eSjbii3Y2gjVfHzl6l3Rr7w1Qp
mPaqf8p+ptDOAE8SzpxlOT/3ko04X6urkM2i3c0mRbu17qgNpl21YagDhzfR
3nSuiPZnFjO9wPO026ip97tpd2sPxbCl3d0Ommh3r2HdllXaySLQ6mF2LkB7
lu4TaSf9GaCFOQe0W4wBoi6lNumwq0f94I0A5+9JtNucWs7P7WSB59E9aDO3
SDRdHbvG7hY/VcAAPFXao6H2TQTnlLuRZTGzlvYpqMsBYEhsV2RKuulgO+m2
91m0V89oB7wcoRvJRcgCcAbq/OER6iN99tHIzHEccuZc5fVyhG4kSxEOU18K
jJAJUAcMgGGMkK8ajKdPtLZ4hbOeGafdAiNXvrRnzKcKvH0fABOlTNMAmtRn
ud3Ag8ZV2r+Cv4OXArRL5tXKl9fyqEHaWwvdKF+qSODqwk06kkwy4/rKGJd2
e3Usz7Kcpf2lvJ0JVh/w3ZxjxjAkNi8Y8yRNWJ0i6pM0c7mq0djcbbH8uJyl
/VWlXdkgudVGqLs/Vgnps82+ljztaunIU9uPZCyqE7fAy96W47S5SFxVCFqZ
d21cZhCGrQN1MFSS5FnNZEv3TZdzsKTA3hP4KbTz2GDaz0BoEHLVuX3f0siY
8/hius6QtI/I9Q2yhmfoPYgLwCYM+mjv4B/4A2g5ODsyWXAeLYdqT7lYuqBa
XHEWMA7vsuGCNAuepgZ962nzq3WoYAHJLFjO1Z6KaIxoB7fySNQL7YAT/Gkf
7Txa3airoeJVakJduUTae19c5HoCG6nSzhhO6aEDp3GEWmnnR/gMKpm+oYKl
S9qnoG6DcpiKRd0/ZPAGqPfRfgbq48CrxlHPTcMA0WFWO2m3qDPfMGKAW5l3
Q8zjZF2uFSd5iMzrw7u5wQzPnU6UR/yoQA9Je6sO861EB+0dqEtCyNCQqPPA
4/y1X7xWaQdz5EfITCFyj0SdDxC2DowHmRoSG8ktuGi1eaFQjM7C2Cam3d44
wisJ5gJOhw1cbRbVwEktB2wf8b6t9uVqyKqcv3QEdzUZnKqj7QBevWMfacCL
aUf49C5aW0cb7Sx4qasD/jRVnS3yNLxpksGytEcBckGyJt9KO7MFqM4BP2qQ
oD0zPPsan1e2ZHLzAxXRXrVZu87VoEQ9kDfe7cAinyd9stretcqq01YTXLXH
PTStKn/qjxWw9wsWOUqWiDplXwD1QYcHm4X68STYBpd0OVd7KgrulaGxh1d5
i9LTpg+GPwK++DnINTvmQdQT1Gs07s99B4IK5DCXexj1CEWyPePw9pAOZ0ht
rmpJ0I169JjZEdwArKKrbBy0Bz3gw91MnLva1cVfjsRbimFmFurR/RZ8Xx3Q
3oS6S7tb0kTJOHfNn9xDoUn+RCnqLJN9C45pj4AHxls15BHg3fMO0g7akwPI
Umqu5MJGqDOd2GavNwHtzC306KNWwkFCAd74+/DRmgCjaKJdDns5M/cVIIdf
XrclT3s17oOod9N+iHqpg7Q+PpmUX47NTYU3+pE9lKFdmicJ4UTaMWNW3YvQ
d5Q72aS9W65vlMUcdBKSdt7ku1GXtEeTcvsfRH08Ou58k/bu9TxvlyzB6gAe
VC9uwU/SLr2xmkqz7H1wAe3wkva+xTzbxDpo57ntEL9l8GXVeemQtM/l8IL9
mgG+w6Ln0j4L9ekrmbRPhNBG9owTYeD7CpJx4A9RNVVpx2+CBJmyekn7+DLO
MvZqxF3gR4gdVAR5+RT8qPKlNDjP5909aDk/99I47ZFpRza4lcComNGqw3GO
lwbdkUraBzVCO1OcuOFeDjlDO3+43dRc+A/vL+Qn7begHXOO75zfBWamf/kC
0x7tgB3AywEsR+hGsqEh17x6dwXv6W8gdy4A9XHgI9r7StAPlLLB6opVLf1G
qJ9t+yTtPPDVZUzgq+jOpR0EWp5u7T2Zs7MvmjUAnt9V3WVs6uejZAPBF+2Y
doy6POPmtx8n0u6e1F09HvjovCUEyxlbLnf9XUT7aI8C7UZnLeoSv4tRx/UM
6TbReibtapVIQ57SD7CghbSrHe082vFHffYOaOdT5u31/P6Xi4AdWeYV/26w
eNTPo7cPyytHVc7YXb2rqwBFe6L+0vHdUS32JQqYfLXmqoZxETrbya/MrOnD
Hq9ksoaprpL1eZf2ciyz7EewidtzzYX/drS7BTzJKr4IStrBKkUhqF6rPtp/
d/hseJYz3Ee7uoiorjye6XLM9lFTCB4DfxdiCTzLGe6mvVo3urTbKaexuwtF
hkCxTaIuS/omBkbK+/ejPUIXVDJJu10rAEa04E9zicqg3kd764EL95SzaXex
f4pbOqrP5XTtqSbg3QU/qYbpAL771KsqLoZtsMm6g8fFTwogStKOOxlEvUq7
vX1qAWDY2412GyD1jpqaG6CUS3sUdMkwSftcY2dodx9XODaubfhyRS41jld5
czlRm0tui+7OWLWdVtqjR2uYTyPUwcMPy/EGacigzrhT0t4KfMRGNUySfCb0
7pMhWHzWqOTdjfYOY6+iLs+ynKVbCFBRJfwxVrrPpT0a9nLaeeYttHZriM6y
HKRbiKE9gv8M2o/a3Uu+4DmE4S+kvUMKdbXIdspJezfw9vmZCHg3KN2od2fK
Wp4x6n3MY9TdKSfwfcC7tLuBk4c3uejFlK4qafqM3VqHpT3tfSLth/gy2tIS
udD1OGHAlpy6g/ZH7OSq5+giJYEfAf74XhxG/IAAfRrqFrymusUCr3pWqKtc
KK+XU3QjqXV2v7txQ/zYwOH3SbqjsWJ3F78QbmnH4VhO0Y0klxHbu1r8JcBb
P9wE9SZXLyvv5otccIl0VPMsR+hekrRH384fZmONrPW8q9GtiqgO4AHqVmq1
3WNttymG9gj4agia2OtLBIvNcra7UZcvyLVyeXYzKMUDr5BWVY0FXtUzDOok
7WAT2ZB2voaRL0jUI9pTp9Lumn+TvZPfDUU3//fknKT9EdyBcWcEapjUNcC7
4bCh5DHmidoTdcVqE+qAdmsmqQuAP+Iyu0SkifZWVW++bSWynlGoq3eUISzn
4b1labdf5KmPOioNxuFV3T4IoR0/eex0zl3a7WoXG0ldBny1nnFjPeKQmFUM
WxXF6aceoV31n5ela4GPHllUDGD7IpkcTIfSsxptRxp2jLAbdfdcifr1KobD
PGfLAH8G6laA9ik5NYX2RH03qWIS34E/TJ15kpOfTTtuBhBVUougxpCobyhc
zyg2VKAfs/8Wxwjt/OGgcbVCi1B/mG/fZN2VqO+jqsO7cVc9LDH56XKTl0H9
8f3CP0qZ5bFOPRqBd5m/BnimKp7bP1/A4BomUd9KLvAqXiTw5zFvmVGYnQ28
nWlUwCTqO0vGiL/Fd6XJ2wpKnhHA1noWl3w7wWhBEvVbSF5VdQBvrW866hE5
U4B3QX0GVyhgKZL2u+j5898sOzyHl8gBGhXzF6D+gFV0U/9NqJP5sjymKSAZ
rCbgLZZT6grZZ1RIux8dXlniYukmi12Z1lRK1PfXMyjgwbdOwBL7zNZFvYwt
IrNq7+AdzLnqv+rqr7VaHsoUo2dQwINHFsGvZrTWGFUDx+kQnQ6UK62oM493
prHfSJHDW0hkGxck2Wer1JAwrrNOZJeiaXtKY7+jVASrwGOjlj134IfP1Qot
0/7RVYblryPdVE9Tq/QBD2hkkJMt3RM1AczPvTo196Mv4h95T+0pAHz384et
Bvtor0wGp8xw7jZIY7+7nvEVa98jiFX4dxAz8uj95SFLjagKPIj+XPFwPoNb
NyOEM8NbHqzUuJ4/v2ONhPf3U8m/5lz2/mrS/t46av+g0vXAX8M5/z3y8hil
ZqnUM1WTv9h4r5Gakf1xeYBSc8UA33F/cnPZWch3xu8CpbZVH/AuM7eQO2yZ
yMsjkjpV3Q4/hXb7iMJcqssI3dGquSyPReoCNQEvUcHwgJaS9nGS3TRk7mom
6p8pEnj3AtalCMM57ti2GiFbyvaJ+seqUMEzX3VmEnWyOppeR+2Jeubglevc
Cnw1EcjUwPA3VSnlvEdcLK0iikzVr3zS+KpwzALe8t+0WZAG3rH1rELdTerX
UNWQXhNfDsMn6DzgxzeIvsN3QP3xk3b7Tpld0r5Kc6uaQdpnJcvyWl0hbXex
hyh1fjRejsFHaTnwU4x9E9QfP2mXbH/Ba5mk/XqtNflu2u0F8nLUH78exosu
xtXwspJZJff+5AUp8E6oP0w1bi8oZOOkfa1cnx8srafTboe3A+dlASXDX7BW
Sdp30JXM8926W89WqD88bweNk/Z9BJgnb4ZHh7TedbwF52XRkvb7Sn4BxGNc
BZthHhy7SZXuLpeqZKKi/ZG0byyA/ZRipsq/vNGxfDXAKilvB6PdfC6pB/Ec
iMuwewifCzd6kupLXJlWaU97v5HAo1xVPqtZcyPCpZq8PWn/QPE5sr+S9rfU
SVjeGvVH0v6mOsmH34n2ai2XtN9C71F1nKEIYFutvS5Plg84VVXSHqnpa4hc
vU30FP9SmPup+1xf6vFeF90fohKjKFhJe+ptVEwJ2HvSnnoPMbTP2qYzZVLL
JWm3QGZRmnpLJe2pzxEuZpYPL5WaqKQ99TlKqlOfo6Q9lUqlUql99H8TY88T

    "], {{0, 228}, {250, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
    Automatic],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{250, 228},
  PlotRange->{{0, 250}, {0, 228}}]], "Output",
 CellChangeTimes->{3.5912460055957336`*^9, 3.591247326831171*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Clustering Alarms (Booleans)", "Title"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.5912473632414103`*^9, 3.591247383242895*^9}}],

Cell["\<\


Make a random set of alarms, uniformly distributed \
\>", "Text",
 CellChangeTimes->{{3.591247929445476*^9, 3.591247939288452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"alarms", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"RandomInteger", "[", "]"}], "\[Equal]", "1"}], ",", " ", 
         "True", ",", " ", "False"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", " ", ",", "2500"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"j", ",", " ", "1", ",", " ", "100"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"alarms", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.591247499375143*^9, 3.591247626272396*^9}, {
   3.591247846343339*^9, 3.591247846476575*^9}, {3.5912483712131433`*^9, 
   3.591248410037507*^9}, 3.591248443461462*^9, {3.5912485005787077`*^9, 
   3.591248500847796*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "False", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "False", ",", "False", ",", 
   "False", ",", "True", ",", "False", ",", "True", ",", "False", ",", 
   "False", ",", "True", ",", "False", ",", "False", ",", "True", ",", "True",
    ",", "False", ",", "True", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "True", ",", "False", ",", 
   "True", ",", "True", ",", "True", ",", "False", ",", "False", ",", "True", 
   ",", "False", ",", "True", ",", "True", ",", "False", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "False", ",", "False", ",", "True", 
   ",", "False", ",", "False", ",", "True", ",", "True", ",", "False", ",", 
   "True", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "True", ",", "True", ",", "True",
    ",", "True", ",", "False", ",", "True", ",", "True", ",", "True", ",", 
   "False", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
   "False", ",", "True", ",", "True", ",", "True", ",", "False", ",", "False",
    ",", "True", ",", "True", ",", "True", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "True", ",", "True", ",", "False", ",", "True",
    ",", "True", ",", "False", ",", "False", ",", "True", ",", "False", ",", 
   "False", ",", "True", ",", "False"}], "}"}]], "Output",
 CellChangeTimes->{
  3.591247586095299*^9, 3.591247631218552*^9, 3.591247847355032*^9, {
   3.591248374655911*^9, 3.591248410500445*^9}, 3.591248443801756*^9, 
   3.591248501775632*^9, 3.591248754192315*^9, 3.59124895187022*^9, 
   3.591248992917089*^9, 3.5912491334323063`*^9, 3.591249209372086*^9, 
   3.591249250290291*^9, {3.591249281665553*^9, 3.591249324583438*^9}, 
   3.5912495705498667`*^9, 3.591251250144816*^9, 3.59125135107938*^9}]
}, Open  ]],

Cell["\<\

Large size 6-clusters, no anomalies:\
\>", "Text",
 CellChangeTimes->{{3.5912479476255007`*^9, 3.591247985357782*^9}, {
  3.591248549977256*^9, 3.591248552259337*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numClusters", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"clusters", "=", 
   RowBox[{"ClusteringComponents", "[", 
    RowBox[{"alarms", ",", "numClusters", ",", "1", ",", 
     RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.591247420065596*^9, 3.5912474202911787`*^9}, {
   3.59124764655299*^9, 3.5912476903481283`*^9}, 3.591247816598318*^9, 
   3.591247902773398*^9, {3.591248173428134*^9, 3.59124817511274*^9}, 
   3.591248227730679*^9, 3.591248347713382*^9, 3.591248448354541*^9, 
   3.5912485449928102`*^9, {3.591248745795141*^9, 3.591248746233923*^9}, {
   3.5912490223104563`*^9, 3.5912490385893507`*^9}, 3.591249136421052*^9}],

Cell["\<\

The following population size per cluster indicates NORMAL in that interval \
of time:\
\>", "Text",
 CellChangeTimes->{{3.5912494046211*^9, 3.5912494260065804`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Count", "[", 
     RowBox[{"clusters", ",", "i"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", "numClusters"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.591248179699383*^9, 3.591248200884782*^9}, {
   3.591248234119856*^9, 3.591248234490901*^9}, {3.5912483511881857`*^9, 
   3.591248351604212*^9}, {3.591248579429408*^9, 3.591248579912956*^9}, {
   3.5912487590474663`*^9, 3.5912487595874643`*^9}, 3.59124904160506*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"480", ",", "767", ",", "420", ",", "82", ",", "393", ",", "358"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.591248203269395*^9, 3.591248234777631*^9}, 
   3.5912483522707653`*^9, {3.591248405430331*^9, 3.591248420742238*^9}, 
   3.591248479571855*^9, 3.591248520671851*^9, {3.591248573897204*^9, 
   3.591248580252015*^9}, 3.591248765082436*^9, 3.5912489736313*^9, 
   3.5912490055235767`*^9, 3.591249048624988*^9, 3.591249152374382*^9, 
   3.591249229835814*^9, {3.591249273120329*^9, 3.5912493456271553`*^9}, 
   3.591249588820981*^9, 3.591251268423802*^9, 3.5912513688202267`*^9}]
}, Open  ]],

Cell["\<\

Now take a small percentage of the alarms and bias them towards False:\
\>", "Text",
 CellChangeTimes->{{3.591249429720155*^9, 3.5912494486978827`*^9}, {
  3.591249493000708*^9, 3.5912494933270397`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"alarms", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "\[GreaterEqual]", " ", "2200"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomInteger", "[", "5", "]"}], "\[Equal]", "1"}], ",", 
           " ", "True", ",", " ", "False"}], "]"}], ",", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomInteger", "[", "]"}], "\[Equal]", "1"}], ",", " ", 
           "True", ",", " ", "False"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", " ", ",", "2500"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"j", ",", " ", "1", ",", " ", "100"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"alarms", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"alarms", "[", 
    RowBox[{"[", "2400", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.591248619832427*^9, 3.591248630989349*^9}, {
  3.591248874046299*^9, 3.591248906817827*^9}, {3.591249453390621*^9, 
  3.591249465006619*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "False", ",", "True", ",", "False", ",", "True", ",", "False", 
   ",", "True", ",", "True", ",", "False", ",", "True", ",", "True", ",", 
   "False", ",", "True", ",", "False", ",", "True", ",", "True", ",", "False",
    ",", "False", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
   "True", ",", "True", ",", "False", ",", "False", ",", "False", ",", "True",
    ",", "True", ",", "False", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "True", ",", "False", ",", "False", ",", "False",
    ",", "False", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "True", ",", "True", ",", "True",
    ",", "True", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
   "True", ",", "True", ",", "False", ",", "False", ",", "True", ",", "False",
    ",", "True", ",", "False", ",", "True", ",", "True", ",", "True", ",", 
   "True", ",", "True", ",", "False", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "False", ",", "False", ",", "False", ",", 
   "True", ",", "True", ",", "True", ",", "False", ",", "False", ",", "True", 
   ",", "False", ",", "False", ",", "True", ",", "False", ",", "False", ",", 
   "False", ",", "True", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False"}], "}"}]], "Output",
 CellChangeTimes->{
  3.591248632871641*^9, 3.591248791380103*^9, 3.591248909282152*^9, 
   3.5912490825618753`*^9, 3.591249156615369*^9, 3.5912493484906816`*^9, 
   3.591249466284047*^9, {3.591249592284466*^9, 3.591249594954094*^9}, 
   3.591251275451715*^9, 3.591251372142603*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "False", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "True", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "True", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "True", ",", "False", ",", 
   "False", ",", "True", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "True", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
   "False", ",", "False", ",", "True", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "True", ",", "True", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.591248632871641*^9, 3.591248791380103*^9, 3.591248909282152*^9, 
   3.5912490825618753`*^9, 3.591249156615369*^9, 3.5912493484906816`*^9, 
   3.591249466284047*^9, {3.591249592284466*^9, 3.591249594954094*^9}, 
   3.591251275451715*^9, 3.591251372144253*^9}]
}, Open  ]],

Cell["\<\

Try to cluster the biased alarms into 6 clusters:\
\>", "Text",
 CellChangeTimes->{{3.5912495067492113`*^9, 3.591249529878469*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"clusters", "=", 
   RowBox[{"ClusteringComponents", "[", 
    RowBox[{"alarms", ",", "numClusters", ",", "1", ",", 
     RowBox[{"Method", "\[Rule]", "\"\<KMeans\>\""}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.591248643035084*^9, 3.5912486432061043`*^9}, {
   3.5912487188749037`*^9, 3.5912487190312*^9}, {3.5912487940466757`*^9, 
   3.5912488111695147`*^9}, {3.591248932063197*^9, 3.591248933164921*^9}, 
   3.59124906696354*^9, 3.59125127738953*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "1", ",", "1", ",", "3", ",", "4", ",", "4", ",", "4", 
   ",", "2", ",", "3", ",", "4", ",", "1", ",", "3", ",", "4", ",", "2", ",", 
   "1", ",", "2", ",", "1", ",", "4", ",", "4", ",", "2", ",", "4", ",", "2", 
   ",", "4", ",", "1", ",", "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", 
   "1", ",", "2", ",", "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", "1", 
   ",", "2", ",", "2", ",", "1", ",", "3", ",", "1", ",", "2", ",", "1", ",", 
   "2", ",", "4", ",", "1", ",", "2", ",", "2", ",", "2", ",", "4", ",", "4", 
   ",", "1", ",", "4", ",", "1", ",", "4", ",", "2", ",", "4", ",", "3", ",", 
   "4", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1", ",", "4", ",", "2", 
   ",", "2", ",", "4", ",", "2", ",", "2", ",", "3", ",", "2", ",", "2", ",", 
   "2", ",", "1", ",", "4", ",", "1", ",", "2", ",", "2", ",", "1", ",", "2", 
   ",", "2", ",", "2", ",", "1", ",", "2", ",", "4", ",", "2", ",", "2", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "3", ",", "2", ",", "2", 
   ",", "1", ",", "2", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", 
   "4", ",", "4", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", "4", 
   ",", "4", ",", "3", ",", "1", ",", "4", ",", "1", ",", "3", ",", "4", ",", 
   "2", ",", "1", ",", "2", ",", "1", ",", "3", ",", "1", ",", "2", ",", "1", 
   ",", "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "4", ",", 
   "2", ",", "3", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "4", 
   ",", "1", ",", "1", ",", "3", ",", "2", ",", "2", ",", "2", ",", "4", ",", 
   "1", ",", "3", ",", "4", ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", 
   ",", "4", ",", "1", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", 
   "4", ",", "2", ",", "1", ",", "4", ",", "4", ",", "2", ",", "3", ",", "1", 
   ",", "1", ",", "4", ",", "4", ",", "1", ",", "4", ",", "1", ",", "1", ",", 
   "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "4", ",", "1", 
   ",", "2", ",", "1", ",", "3", ",", "1", ",", "4", ",", "4", ",", "4", ",", 
   "1", ",", "4", ",", "2", ",", "1", ",", "1", ",", "2", ",", "4", ",", "2", 
   ",", "2", ",", "4", ",", "4", ",", "1", ",", "3", ",", "2", ",", "4", ",", 
   "1", ",", "2", ",", "2", ",", "1", ",", "2", ",", "4", ",", "4", ",", "1", 
   ",", "2", ",", "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "2", 
   ",", "1", ",", "2", ",", "4", ",", "1", ",", "4", ",", "5", ",", "1", ",", 
   "3", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "3", ",", "4", 
   ",", "2", ",", "2", ",", "4", ",", "4", ",", "4", ",", "4", ",", "1", ",", 
   "1", ",", "2", ",", "4", ",", "4", ",", "1", ",", "2", ",", "1", ",", "1", 
   ",", "2", ",", "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "3", ",", 
   "4", ",", "2", ",", "2", ",", "4", ",", "1", ",", "3", ",", "1", ",", "3", 
   ",", "2", ",", "2", ",", "4", ",", "2", ",", "4", ",", "4", ",", "1", ",", 
   "4", ",", "1", ",", "5", ",", "2", ",", "2", ",", "1", ",", "1", ",", "1", 
   ",", "4", ",", "2", ",", "2", ",", "4", ",", "2", ",", "1", ",", "2", ",", 
   "4", ",", "1", ",", "1", ",", "1", ",", "4", ",", "1", ",", "4", ",", "2", 
   ",", "4", ",", "4", ",", "2", ",", "4", ",", "2", ",", "1", ",", "3", ",", 
   "1", ",", "1", ",", "1", ",", "4", ",", "2", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "4", ",", "1", ",", "1", ",", "4", ",", "1", ",", "4", ",", 
   "4", ",", "4", ",", "4", ",", "2", ",", "1", ",", "2", ",", "4", ",", "1", 
   ",", "1", ",", "4", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", 
   "1", ",", "4", ",", "1", ",", "1", ",", "4", ",", "2", ",", "1", ",", "4", 
   ",", "1", ",", "1", ",", "4", ",", "4", ",", "4", ",", "2", ",", "1", ",", 
   "4", ",", "1", ",", "4", ",", "4", ",", "1", ",", "1", ",", "2", ",", "2", 
   ",", "2", ",", "1", ",", "1", ",", "4", ",", "2", ",", "2", ",", "2", ",", 
   "2", ",", "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "2", ",", "1", 
   ",", "1", ",", "3", ",", "2", ",", "1", ",", "1", ",", "1", ",", "3", ",", 
   "1", ",", "4", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1", ",", "2", 
   ",", "1", ",", "1", ",", "4", ",", "4", ",", "2", ",", "3", ",", "1", ",", 
   "2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", 
   ",", "4", ",", "4", ",", "4", ",", "4", ",", "1", ",", "2", ",", "1", ",", 
   "4", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", 
   ",", "4", ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", 
   "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", "1", ",", "4", ",", "5", 
   ",", "1", ",", "2", ",", "4", ",", "2", ",", "2", ",", "3", ",", "1", ",", 
   "2", ",", "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", "4", 
   ",", "2", ",", "2", ",", "4", ",", "1", ",", "2", ",", "2", ",", "4", ",", 
   "4", ",", "4", ",", "2", ",", "4", ",", "4", ",", "2", ",", "5", ",", "4", 
   ",", "2", ",", "1", ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", 
   "2", ",", "1", ",", "2", ",", "2", ",", "4", ",", "1", ",", "1", ",", "1", 
   ",", "4", ",", "4", ",", "1", ",", "2", ",", "3", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "1", ",", "3", ",", "2", 
   ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", "4", ",", "3", ",", 
   "3", ",", "4", ",", "4", ",", "2", ",", "1", ",", "4", ",", "1", ",", "4", 
   ",", "2", ",", "3", ",", "1", ",", "2", ",", "1", ",", "2", ",", "3", ",", 
   "5", ",", "2", ",", "1", ",", "1", ",", "4", ",", "2", ",", "2", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", "2", ",", "2", ",", 
   "1", ",", "4", ",", "1", ",", "2", ",", "1", ",", "1", ",", "4", ",", "2", 
   ",", "1", ",", "4", ",", "1", ",", "1", ",", "4", ",", "1", ",", "2", ",", 
   "3", ",", "4", ",", "3", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", "2", ",", "4", ",", 
   "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "4", ",", "2", ",", "1", 
   ",", "2", ",", "2", ",", "1", ",", "1", ",", "3", ",", "2", ",", "1", ",", 
   "4", ",", "4", ",", "1", ",", "3", ",", "1", ",", "2", ",", "3", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "4", ",", "4", ",", 
   "3", ",", "2", ",", "4", ",", "2", ",", "1", ",", "3", ",", "4", ",", "4", 
   ",", "2", ",", "4", ",", "1", ",", "4", ",", "1", ",", "2", ",", "4", ",", 
   "4", ",", "4", ",", "1", ",", "2", ",", "2", ",", "4", ",", "2", ",", "1", 
   ",", "1", ",", "4", ",", "3", ",", "1", ",", "2", ",", "1", ",", "2", ",", 
   "2", ",", "4", ",", "4", ",", "4", ",", "1", ",", "4", ",", "2", ",", "1", 
   ",", "3", ",", "3", ",", "1", ",", "2", ",", "4", ",", "4", ",", "4", ",", 
   "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2", ",", "2", 
   ",", "2", ",", "2", ",", "2", ",", "1", ",", "1", ",", "4", ",", "4", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "4", ",", "3", ",", "1", 
   ",", "2", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "4", ",", "4", ",", "1", ",", "1", 
   ",", "2", ",", "1", ",", "2", ",", "2", ",", "4", ",", "1", ",", "4", ",", 
   "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", "1", ",", "4", ",", "1", 
   ",", "3", ",", "4", ",", "1", ",", "4", ",", "4", ",", "1", ",", "4", ",", 
   "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", "1", ",", "2", ",", "2", 
   ",", "1", ",", "2", ",", "1", ",", "1", ",", "4", ",", "4", ",", "3", ",", 
   "1", ",", "1", ",", "5", ",", "4", ",", "2", ",", "1", ",", "4", ",", "4", 
   ",", "4", ",", "1", ",", "4", ",", "3", ",", "1", ",", "1", ",", "2", ",", 
   "4", ",", "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "2", ",", "1", ",", "2", ",", "2", ",", "2", ",", "1", ",", 
   "3", ",", "1", ",", "1", ",", "3", ",", "1", ",", "4", ",", "2", ",", "1", 
   ",", "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", "4", ",", "4", ",", 
   "2", ",", "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "4", ",", "4", 
   ",", "3", ",", "1", ",", "4", ",", "1", ",", "3", ",", "2", ",", "4", ",", 
   "1", ",", "4", ",", "4", ",", "2", ",", "2", ",", "4", ",", "1", ",", "1", 
   ",", "2", ",", "2", ",", "5", ",", "1", ",", "2", ",", "1", ",", "1", ",", 
   "1", ",", "4", ",", "1", ",", "1", ",", "2", ",", "2", ",", "2", ",", "1", 
   ",", "2", ",", "1", ",", "2", ",", "4", ",", "1", ",", "1", ",", "4", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2", 
   ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "1", ",", "2", ",", 
   "2", ",", "4", ",", "4", ",", "1", ",", "4", ",", "1", ",", "1", ",", "4", 
   ",", "1", ",", "4", ",", "4", ",", "1", ",", "4", ",", "2", ",", "1", ",", 
   "1", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", "4", ",", "1", 
   ",", "4", ",", "4", ",", "2", ",", "2", ",", "3", ",", "2", ",", "4", ",", 
   "2", ",", "2", ",", "4", ",", "4", ",", "1", ",", "4", ",", "4", ",", "4", 
   ",", "4", ",", "2", ",", "4", ",", "2", ",", "5", ",", "4", ",", "4", ",", 
   "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", 
   ",", "2", ",", "4", ",", "4", ",", "4", ",", "2", ",", "2", ",", "4", ",", 
   "4", ",", "4", ",", "3", ",", "2", ",", "2", ",", "2", ",", "4", ",", "1", 
   ",", "4", ",", "4", ",", "1", ",", "3", ",", "4", ",", "1", ",", "1", ",", 
   "4", ",", "4", ",", "2", ",", "1", ",", "3", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "2", ",", "4", ",", "2", ",", "4", ",", "4", ",", "1", ",", 
   "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "4", 
   ",", "4", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", 
   "1", ",", "2", ",", "4", ",", "4", ",", "4", ",", "1", ",", "1", ",", "2", 
   ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", 
   "2", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", "4", ",", "1", 
   ",", "4", ",", "2", ",", "4", ",", "4", ",", "4", ",", "4", ",", "4", ",", 
   "3", ",", "4", ",", "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "1", 
   ",", "1", ",", "4", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", 
   "4", ",", "2", ",", "4", ",", "4", ",", "1", ",", "2", ",", "4", ",", "4", 
   ",", "2", ",", "4", ",", "1", ",", "2", ",", "3", ",", "1", ",", "1", ",", 
   "1", ",", "4", ",", "1", ",", "2", ",", "1", ",", "2", ",", "4", ",", "4", 
   ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2", ",", 
   "4", ",", "4", ",", "2", ",", "4", ",", "2", ",", "1", ",", "4", ",", "1", 
   ",", "4", ",", "4", ",", "4", ",", "1", ",", "4", ",", "2", ",", "1", ",", 
   "3", ",", "2", ",", "1", ",", "4", ",", "1", ",", "2", ",", "2", ",", "2", 
   ",", "2", ",", "1", ",", "1", ",", "4", ",", "1", ",", "1", ",", "3", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "4", ",", "1", ",", "2", 
   ",", "4", ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", ",", "1", ",", 
   "2", ",", "2", ",", "4", ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", 
   ",", "3", ",", "4", ",", "1", ",", "2", ",", "2", ",", "1", ",", "2", ",", 
   "4", ",", "4", ",", "2", ",", "4", ",", "4", ",", "1", ",", "1", ",", "1", 
   ",", "4", ",", "2", ",", "3", ",", "1", ",", "1", ",", "2", ",", "2", ",", 
   "4", ",", "3", ",", "2", ",", "3", ",", "4", ",", "1", ",", "2", ",", "2", 
   ",", "1", ",", "4", ",", "4", ",", "2", ",", "1", ",", "4", ",", "3", ",", 
   "2", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", "2", ",", "1", 
   ",", "4", ",", "1", ",", "1", ",", "3", ",", "1", ",", "2", ",", "4", ",", 
   "4", ",", "4", ",", "3", ",", "4", ",", "1", ",", "1", ",", "2", ",", "4", 
   ",", "2", ",", "2", ",", "1", ",", "4", ",", "3", ",", "2", ",", "3", ",", 
   "1", ",", "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", "4", 
   ",", "4", ",", "1", ",", "2", ",", "4", ",", "2", ",", "5", ",", "2", ",", 
   "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", "2", ",", "1", ",", "1", 
   ",", "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "2", ",", "1", ",", "1", ",", "4", ",", "2", ",", "1", ",", "1", ",", "4", 
   ",", "1", ",", "4", ",", "1", ",", "4", ",", "5", ",", "1", ",", "2", ",", 
   "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "4", ",", "2", 
   ",", "1", ",", "2", ",", "2", ",", "1", ",", "4", ",", "4", ",", "2", ",", 
   "1", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", "1", ",", "2", 
   ",", "1", ",", "2", ",", "2", ",", "4", ",", "1", ",", "4", ",", "4", ",", 
   "2", ",", "2", ",", "1", ",", "2", ",", "2", ",", "3", ",", "4", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "3", ",", "4", ",", "2", ",", "3", ",", 
   "4", ",", "2", ",", "2", ",", "1", ",", "1", ",", "2", ",", "2", ",", "2", 
   ",", "2", ",", "4", ",", "1", ",", "4", ",", "2", ",", "4", ",", "4", ",", 
   "4", ",", "4", ",", "4", ",", "2", ",", "1", ",", "1", ",", "2", ",", "4", 
   ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", 
   "1", ",", "1", ",", "3", ",", "1", ",", "1", ",", "2", ",", "4", ",", "4", 
   ",", "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", "2", ",", "4", ",", "4", 
   ",", "4", ",", "2", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "3", ",", "1", ",", "4", ",", "4", ",", "1", ",", "1", 
   ",", "1", ",", "4", ",", "4", ",", "2", ",", "4", ",", "1", ",", "1", ",", 
   "2", ",", "2", ",", "5", ",", "4", ",", "1", ",", "2", ",", "4", ",", "4", 
   ",", "4", ",", "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "3", ",", 
   "2", ",", "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "4", 
   ",", "2", ",", "4", ",", "1", ",", "4", ",", "2", ",", "2", ",", "3", ",", 
   "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "2", ",", "4", ",", "2", 
   ",", "2", ",", "4", ",", "1", ",", "2", ",", "4", ",", "4", ",", "3", ",", 
   "3", ",", "2", ",", "4", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", 
   ",", "2", ",", "4", ",", "2", ",", "2", ",", "3", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "4", ",", "4", ",", "4", ",", "2", 
   ",", "4", ",", "1", ",", "2", ",", "3", ",", "2", ",", "4", ",", "1", ",", 
   "1", ",", "2", ",", "4", ",", "4", ",", "2", ",", "1", ",", "2", ",", "1", 
   ",", "4", ",", "2", ",", "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "2", ",", "3", ",", "4", ",", "4", ",", "4", ",", "1", ",", "3", ",", "1", 
   ",", "3", ",", "1", ",", "4", ",", "2", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "4", ",", "4", ",", "2", ",", "1", 
   ",", "1", ",", "2", ",", "4", ",", "2", ",", "2", ",", "1", ",", "1", ",", 
   "4", ",", "1", ",", "4", ",", "4", ",", "2", ",", "2", ",", "2", ",", "1", 
   ",", "3", ",", "1", ",", "1", ",", "4", ",", "4", ",", "2", ",", "2", ",", 
   "1", ",", "4", ",", "2", ",", "2", ",", "2", ",", "3", ",", "2", ",", "4", 
   ",", "1", ",", "2", ",", "4", ",", "3", ",", "4", ",", "1", ",", "2", ",", 
   "4", ",", "4", ",", "1", ",", "4", ",", "3", ",", "1", ",", "2", ",", "4", 
   ",", "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "4", ",", 
   "3", ",", "1", ",", "4", ",", "2", ",", "1", ",", "4", ",", "4", ",", "2", 
   ",", "1", ",", "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", "2", ",", 
   "4", ",", "1", ",", "2", ",", "2", ",", "2", ",", "4", ",", "2", ",", "3", 
   ",", "3", ",", "1", ",", "4", ",", "4", ",", "1", ",", "2", ",", "2", ",", 
   "2", ",", "1", ",", "1", ",", "2", ",", "2", ",", "4", ",", "2", ",", "2", 
   ",", "2", ",", "1", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "4", ",", "4", ",", "1", ",", "4", ",", "4", 
   ",", "1", ",", "1", ",", "4", ",", "4", ",", "4", ",", "2", ",", "3", ",", 
   "3", ",", "4", ",", "1", ",", "2", ",", "2", ",", "1", ",", "4", ",", "2", 
   ",", "4", ",", "1", ",", "4", ",", "2", ",", "2", ",", "1", ",", "2", ",", 
   "2", ",", "4", ",", "2", ",", "2", ",", "1", ",", "2", ",", "3", ",", "1", 
   ",", "2", ",", "1", ",", "4", ",", "2", ",", "4", ",", "2", ",", "4", ",", 
   "4", ",", "4", ",", "1", ",", "4", ",", "4", ",", "1", ",", "1", ",", "4", 
   ",", "2", ",", "2", ",", "1", ",", "3", ",", "1", ",", "1", ",", "4", ",", 
   "4", ",", "2", ",", "4", ",", "4", ",", "2", ",", "1", ",", "2", ",", "2", 
   ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", "2", ",", "4", ",", 
   "4", ",", "1", ",", "4", ",", "4", ",", "1", ",", "2", ",", "2", ",", "3", 
   ",", "1", ",", "4", ",", "4", ",", "1", ",", "2", ",", "1", ",", "4", ",", 
   "2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", 
   ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", 
   "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", "4", ",", "1", 
   ",", "2", ",", "1", ",", "2", ",", "1", ",", "2", ",", "4", ",", "1", ",", 
   "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", 
   ",", "2", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "4", ",", "4", ",", "3", 
   ",", "4", ",", "1", ",", "2", ",", "2", ",", "3", ",", "4", ",", "2", ",", 
   "3", ",", "1", ",", "1", ",", "2", ",", "1", ",", "4", ",", "1", ",", "4", 
   ",", "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", "2", ",", "4", ",", 
   "1", ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "1", ",", "3", ",", "4", ",", "4", ",", "3", ",", "2", ",", 
   "4", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "4", 
   ",", "2", ",", "2", ",", "2", ",", "1", ",", "4", ",", "2", ",", "4", ",", 
   "3", ",", "2", ",", "3", ",", "4", ",", "4", ",", "4", ",", "2", ",", "4", 
   ",", "2", ",", "1", ",", "4", ",", "2", ",", "1", ",", "1", ",", "4", ",", 
   "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", 
   ",", "4", ",", "2", ",", "1", ",", "1", ",", "1", ",", "4", ",", "2", ",", 
   "2", ",", "4", ",", "1", ",", "4", ",", "4", ",", "2", ",", "1", ",", "2", 
   ",", "4", ",", "2", ",", "4", ",", "4", ",", "4", ",", "4", ",", "1", ",", 
   "2", ",", "2", ",", "1", ",", "1", ",", "4", ",", "2", ",", "2", ",", "4", 
   ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", ",", "2", ",", "2", ",", 
   "1", ",", "4", ",", "4", ",", "3", ",", "2", ",", "1", ",", "2", ",", "2", 
   ",", "3", ",", "1", ",", "2", ",", "4", ",", "2", ",", "3", ",", "1", ",", 
   "4", ",", "4", ",", "1", ",", "3", ",", "4", ",", "4", ",", "2", ",", "1", 
   ",", "1", ",", "4", ",", "4", ",", "2", ",", "1", ",", "1", ",", "2", ",", 
   "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", "4", ",", "1", ",", "2", 
   ",", "3", ",", "4", ",", "4", ",", "4", ",", "4", ",", "2", ",", "4", ",", 
   "4", ",", "1", ",", "4", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", 
   ",", "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "1", ",", "2", ",", 
   "3", ",", "2", ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", ",", "2", 
   ",", "2", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "4", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "4", ",", "4", ",", "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", 
   "1", ",", "2", ",", "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "3", 
   ",", "4", ",", "1", ",", "4", ",", "2", ",", "1", ",", "2", ",", "2", ",", 
   "2", ",", "4", ",", "2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1", 
   ",", "2", ",", "2", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "4", ",", "2", ",", "2", ",", "2", ",", "1", ",", "3", 
   ",", "2", ",", "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "4", ",", 
   "2", ",", "4", ",", "4", ",", "1", ",", "3", ",", "1", ",", "2", ",", "1", 
   ",", "4", ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1", ",", 
   "1", ",", "2", ",", "1", ",", "2", ",", "4", ",", "4", ",", "1", ",", "1", 
   ",", "4", ",", "1", ",", "3", ",", "3", ",", "1", ",", "4", ",", "2", ",", 
   "4", ",", "2", ",", "4", ",", "4", ",", "2", ",", "4", ",", "3", ",", "4", 
   ",", "1", ",", "4", ",", "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", 
   "4", ",", "4", ",", "2", ",", "4", ",", "1", ",", "1", ",", "4", ",", "2", 
   ",", "4", ",", "2", ",", "4", ",", "4", ",", "1", ",", "1", ",", "3", ",", 
   "2", ",", "4", ",", "3", ",", "2", ",", "1", ",", "1", ",", "4", ",", "2", 
   ",", "4", ",", "1", ",", "4", ",", "2", ",", "1", ",", "2", ",", "1", ",", 
   "4", ",", "2", ",", "1", ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "3", ",", "2", ",", "4", ",", "2", ",", "4", ",", "4", ",", 
   "2", ",", "3", ",", "1", ",", "1", ",", "1", ",", "2", ",", "3", ",", "1", 
   ",", "2", ",", "1", ",", "4", ",", "4", ",", "1", ",", "2", ",", "4", ",", 
   "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "4", ",", "2", ",", "2", 
   ",", "2", ",", "2", ",", "4", ",", "1", ",", "3", ",", "4", ",", "2", ",", 
   "1", ",", "2", ",", "2", ",", "1", ",", "2", ",", "4", ",", "1", ",", "4", 
   ",", "2", ",", "2", ",", "1", ",", "4", ",", "4", ",", "1", ",", "3", ",", 
   "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", 
   ",", "2", ",", "2", ",", "2", ",", "4", ",", "4", ",", "1", ",", "2", ",", 
   "3", ",", "2", ",", "4", ",", "4", ",", "4", ",", "1", ",", "2", ",", "2", 
   ",", "2", ",", "4", ",", "1", ",", "4", ",", "1", ",", "1", ",", "4", ",", 
   "1", ",", "2", ",", "2", ",", "2", ",", "3", ",", "1", ",", "2", ",", "3", 
   ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "4", ",", 
   "1", ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", ",", "3", ",", "3", 
   ",", "2", ",", "1", ",", "3", ",", "2", ",", "3", ",", "2", ",", "2", ",", 
   "1", ",", "1", ",", "4", ",", "2", ",", "4", ",", "4", ",", "2", ",", "4", 
   ",", "4", ",", "4", ",", "2", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "2", ",", "2", ",", "4", ",", "1", ",", "4", ",", "4", ",", "2", 
   ",", "1", ",", "4", ",", "1", ",", "1", ",", "4", ",", "4", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "4", ",", "2", ",", "1", ",", "4", ",", "1", 
   ",", "3", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "4", ",", 
   "4", ",", "4", ",", "1", ",", "2", ",", "2", ",", "4", ",", "2", ",", "2", 
   ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", 
   "2", ",", "4", ",", "1", ",", "2", ",", "4", ",", "1", ",", "4", ",", "1", 
   ",", "1", ",", "4", ",", "1", ",", "1", ",", "2", ",", "4", ",", "4", ",", 
   "4", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "4", ",", "4", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "3", ",", "2", ",", "4", 
   ",", "3", ",", "5", ",", "3", ",", "4", ",", "4", ",", "5", ",", "3", ",", 
   "2", ",", "2", ",", "1", ",", "3", ",", "2", ",", "4", ",", "5", ",", "4", 
   ",", "3", ",", "4", ",", "5", ",", "1", ",", "4", ",", "4", ",", "4", ",", 
   "1", ",", "2", ",", "5", ",", "3", ",", "2", ",", "1", ",", "2", ",", "3", 
   ",", "2", ",", "2", ",", "1", ",", "4", ",", "5", ",", "3", ",", "2", ",", 
   "2", ",", "3", ",", "2", ",", "5", ",", "2", ",", "6", ",", "4", ",", "2", 
   ",", "5", ",", "5", ",", "2", ",", "2", ",", "3", ",", "6", ",", "3", ",", 
   "2", ",", "1", ",", "4", ",", "1", ",", "1", ",", "3", ",", "5", ",", "3", 
   ",", "4", ",", "5", ",", "2", ",", "3", ",", "5", ",", "3", ",", "1", ",", 
   "6", ",", "4", ",", "3", ",", "3", ",", "4", ",", "2", ",", "2", ",", "4", 
   ",", "4", ",", "1", ",", "4", ",", "2", ",", "5", ",", "5", ",", "1", ",", 
   "4", ",", "5", ",", "5", ",", "2", ",", "5", ",", "2", ",", "3", ",", "2", 
   ",", "2", ",", "2", ",", "4", ",", "2", ",", "3", ",", "2", ",", "4", ",", 
   "5", ",", "2", ",", "3", ",", "1", ",", "3", ",", "5", ",", "5", ",", "4", 
   ",", "3", ",", "3", ",", "5", ",", "2", ",", "3", ",", "2", ",", "2", ",", 
   "2", ",", "4", ",", "2", ",", "1", ",", "5", ",", "2", ",", "5", ",", "6", 
   ",", "2", ",", "2", ",", "4", ",", "5", ",", "2", ",", "6", ",", "5", ",", 
   "2", ",", "2", ",", "6", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", 
   ",", "1", ",", "3", ",", "1", ",", "4", ",", "1", ",", "5", ",", "5", ",", 
   "5", ",", "1", ",", "1", ",", "5", ",", "2", ",", "1", ",", "1", ",", "5", 
   ",", "1", ",", "2", ",", "5", ",", "3", ",", "3", ",", "2", ",", "5", ",", 
   "2", ",", "4", ",", "1", ",", "3", ",", "6", ",", "3", ",", "1", ",", "4", 
   ",", "5", ",", "3", ",", "4", ",", "4", ",", "1", ",", "4", ",", "3", ",", 
   "3", ",", "6", ",", "5", ",", "2", ",", "4", ",", "1", ",", "4", ",", "4", 
   ",", "4", ",", "1", ",", "3", ",", "1", ",", "4", ",", "4", ",", "4", ",", 
   "1", ",", "5", ",", "2", ",", "1", ",", "3", ",", "1", ",", "2", ",", "5", 
   ",", "4", ",", "5", ",", "2", ",", "1", ",", "2", ",", "5", ",", "1", ",", 
   "3", ",", "1", ",", "4", ",", "4", ",", "2", ",", "2", ",", "3", ",", "2", 
   ",", "5", ",", "1", ",", "5", ",", "3", ",", "4", ",", "2", ",", "1", ",", 
   "5", ",", "1", ",", "5", ",", "1", ",", "2", ",", "2", ",", "5", ",", "3", 
   ",", "1", ",", "2", ",", "4", ",", "4", ",", "2", ",", "4", ",", "3", ",", 
   "1", ",", "3", ",", "1", ",", "3", ",", "4", ",", "4", ",", "2", ",", "2", 
   ",", "3", ",", "2", ",", "1", ",", "1", ",", "3", ",", "3", ",", "3", ",", 
   "2", ",", "5", ",", "1", ",", "2", ",", "4", ",", "4", ",", "3", ",", "5", 
   ",", "4", ",", "1", ",", "2", ",", "1", ",", "4", ",", "2", ",", "2", ",", 
   "5", ",", "1", ",", "1", ",", "4", ",", "2", ",", "6", ",", "5", ",", "2", 
   ",", "4", ",", "3", ",", "2", ",", "1", ",", "2", ",", "3", ",", "1", ",", 
   "5", ",", "1", ",", "3", ",", "5", ",", "3", ",", "1", ",", "4", ",", "2", 
   ",", "2", ",", "2", ",", "3", ",", "2", ",", "2", ",", "1", ",", "2", ",", 
   "4", ",", "2", ",", "4", ",", "3", ",", "4", ",", "1", ",", "3", ",", "2", 
   ",", "3", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.5912513001948147`*^9, 3.5912513953304577`*^9}]
}, Open  ]],

Cell["\<\

Suddenly small cluster sizes show up indicating the ABNORMAL:\
\>", "Text",
 CellChangeTimes->{{3.591249536595602*^9, 3.591249551084985*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Count", "[", 
     RowBox[{"clusters", ",", "i"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", "numClusters"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.591248649423492*^9, 3.591248649832315*^9}, {
   3.591248731812092*^9, 3.591248732159708*^9}, {3.591248797432839*^9, 
   3.591248824343161*^9}, {3.591248938103549*^9, 3.591248938699643*^9}, 
   3.591249071283374*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"818", ",", "793", ",", "182", ",", "638", ",", "60", ",", "9"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.591248653660874*^9, {3.591248726252182*^9, 3.591248732573382*^9}, {
   3.591248798142174*^9, 3.5912488245961103`*^9}, {3.591248917887391*^9, 
   3.5912489450255404`*^9}, {3.591249073277529*^9, 3.591249090490706*^9}, 
   3.591249177676861*^9, 3.5912493688463507`*^9, 3.591249489909307*^9, 
   3.591249613773603*^9, 3.591251312474523*^9, 3.5912514061329823`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n\n",
 StyleBox["Distance Functions ", "Title"],
 "\n\n"
}], "Text",
 CellChangeTimes->{{3.5912461960476627`*^9, 3.591246199770464*^9}, {
  3.591249677526429*^9, 3.59124967767037*^9}}],

Cell["\<\

Get gene textual data:\
\>", "Text",
 CellChangeTimes->{{3.59124624116016*^9, 3.5912462482355824`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sdata", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<GCTAT\>\"", ",", "\"\<TAGGA\>\"", ",", "\"\<GAATT\>\"", ",", 
     "\"\<CATCT\>\"", ",", "\"\<TCAGG\>\"", ",", "\"\<GGGGA\>\"", ",", 
     "\"\<TTACG\>\"", ",", "\"\<GTCAG\>\"", ",", "\"\<TGGAG\>\"", ",", 
     "\"\<GAAAA\>\"", ",", "\"\<ATAGG\>\"", ",", "\"\<TCCGA\>\"", ",", 
     "\"\<TAACT\>\"", ",", "\"\<GTGAT\>\"", ",", "\"\<AAGAA\>\"", ",", 
     "\"\<CCGTA\>\"", ",", "\"\<GCTAA\>\"", ",", "\"\<GCTGG\>\"", ",", 
     "\"\<GAGGG\>\"", ",", "\"\<CTCAT\>\""}], "}"}]}], ";"}]], "Input"],

Cell["\<\


Use the EditDistance metric:\
\>", "Text",
 CellChangeTimes->{{3.591246297343432*^9, 3.591246305712223*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ClusteringComponents", "[", 
  RowBox[{"sdata", ",", 
   RowBox[{"DistanceFunction", "\[Rule]", "EditDistance"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591246262946149*^9, 3.591246269179287*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.591246270050976*^9}]
}, Open  ]],

Cell["\<\

Use Hamming distance, and as you can see we get different clustering \
formations:\
\>", "Text",
 CellChangeTimes->{{3.591246321091848*^9, 3.591246336143641*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"ClusteringComponents", "[", 
   RowBox[{"sdata", ",", 
    RowBox[{"DistanceFunction", "\[Rule]", "HammingDistance"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.59124631289885*^9, 3.591246313048451*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "3", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.591246314984105*^9}]
}, Open  ]]
},
WindowSize->{849, 1359},
WindowMargins->{{165, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Background->RGBColor[1, 1, 1],
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 149, 5, 105, "Text"],
Cell[709, 27, 3140, 87, 336, "Text"],
Cell[3852, 116, 226, 6, 68, "Text"],
Cell[4081, 124, 140, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[4246, 133, 1215, 31, 121, "Input"],
Cell[5464, 166, 955, 19, 50, "Output"]
}, Open  ]],
Cell[6434, 188, 101, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[6560, 196, 1163, 30, 121, "Input"],
Cell[7726, 228, 874, 18, 50, "Output"]
}, Open  ]],
Cell[8615, 249, 100, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[8740, 257, 1163, 30, 121, "Input"],
Cell[9906, 289, 905, 19, 50, "Output"]
}, Open  ]],
Cell[10826, 311, 160, 6, 87, "Text"],
Cell[CellGroupData[{
Cell[11011, 321, 67833, 1118, 136, "Input"],
Cell[78847, 1441, 4359, 79, 134, "Output"]
}, Open  ]],
Cell[83221, 1523, 102, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[83348, 1531, 67760, 1117, 136, "Input"],
Cell[151111, 2650, 5236, 92, 134, "Output"]
}, Open  ]],
Cell[156362, 2745, 103, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[156490, 2753, 58114, 958, 74, "Input"],
Cell[214607, 3713, 12073, 204, 243, "Output"]
}, Open  ]],
Cell[226695, 3920, 101, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[226821, 3928, 58113, 958, 74, "Input"],
Cell[284937, 4888, 8759, 150, 243, "Output"]
}, Open  ]],
Cell[293711, 5041, 160, 5, 105, "Text"],
Cell[293874, 5048, 143, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[294042, 5057, 874, 22, 63, "Input"],
Cell[294919, 5081, 1922, 28, 131, "Output"]
}, Open  ]],
Cell[296856, 5112, 178, 5, 49, "Text"],
Cell[297037, 5119, 747, 14, 46, "Input"],
Cell[297787, 5135, 177, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[297989, 5144, 564, 12, 46, "Input"],
Cell[298556, 5158, 625, 10, 28, "Output"]
}, Open  ]],
Cell[299196, 5171, 214, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[299435, 5180, 1221, 31, 97, "Input"],
Cell[300659, 5213, 1759, 26, 131, "Output"],
Cell[302421, 5241, 1804, 28, 148, "Output"]
}, Open  ]],
Cell[304240, 5272, 142, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[304407, 5280, 514, 9, 46, "Input"],
Cell[304924, 5291, 26456, 337, 1355, "Output"]
}, Open  ]],
Cell[331395, 5631, 152, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[331572, 5639, 513, 12, 46, "Input"],
Cell[332088, 5653, 510, 9, 28, "Output"]
}, Open  ]],
Cell[332613, 5665, 205, 6, 162, "Text"],
Cell[332821, 5673, 114, 4, 49, "Text"],
Cell[332938, 5679, 581, 11, 63, "Input"],
Cell[333522, 5692, 120, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[333667, 5701, 222, 4, 28, "Input"],
Cell[333892, 5707, 306, 6, 28, "Output"]
}, Open  ]],
Cell[334213, 5716, 173, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[334411, 5725, 266, 6, 46, "Input"],
Cell[334680, 5733, 306, 6, 28, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
